==> rbuild-0.0.2.tgz: package/lib/bundler.js <==
var dirname, join, resolve, existsSync, basename, readFile, BundleFile, Bundler, _ref;
_ref = require('path'), dirname = _ref.dirname, join = _ref.join, resolve = _ref.resolve, existsSync = _ref.existsSync, basename = _ref.basename;
readFile = require('fs').readFile;
/**
 *  @class BundleFile
 *
 *  Handles dependencies checking and its own compilation.
 */
BundleFile = (function(){
  BundleFile.displayName = 'BundleFile';
  var last_id, cached, body_re, prototype = BundleFile.prototype, constructor = BundleFile;
  last_id = 0;
  cached = {};
  body_re = /\brequire\s*\(\s*("(\\\"|[^"])*"|'(\\\'|[^'])*')\s*\)/g;
  BundleFile.get = (function(){
    function get(path, extensions){
      if (cached[path]) {
        return cached[path];
      }
      return cached[path] = new BundleFile(path, extensions);
    }
    return get;
  }());
  function BundleFile(path, extensions){
    this.path = path;
    this.extensions = extensions;
    this.compile_fn = null;
    this.error = false;
    this.body = null;
    this.deps = [];
    this.recompile = true;
    this.name = basename(this.path) + "-" + last_id;
    last_id = last_id + 1;
  }
  prototype.getRelativeName = (function(){
    function getRelativeName(path){
      return this.path.replace(dirname(path), '.');
    }
    return getRelativeName;
  }());
  /**
   *  Compiles the module, and parse its contents, triggering the calling of 
   *
   *  @param cbk The callback for when we're done.
   *
   *  @returns An empty string if error, the body of the function otherwise.
   */
  prototype.getBody = (function(){
    function getBody(cbk){
      var ext, fn, realpath, _ref, _this = this;
      if (!this.recompile) {
        cbk(null, this.body);
        return;
      }
      this.recompile = false;
      if (this.compile_fn == null) {
        for (ext in _ref = this.extensions) {
          fn = _ref[ext];
          realpath = this.path + "." + ext;
          if (existsSync(realpath)) {
            this.realpath = realpath;
            this.compile_fn = fn;
            break;
          }
        }
      }
      if (!this.realpath) {
        cbk(new Error("The module " + this.path + " either doesn't exist or doesn't have a valid module handler"));
        return;
      }
      return readFile(this.realpath, 'utf-8', function(err, body){
        if (err) {
          _this.error = true;
          cbk(err, null);
          return;
        }
        if (_this.verbose) {
          console.log("Compiling " + realpath);
        }
        _this.body = _this.compile_fn(body);
        _this.error = false;
        _this.deps = [];
        _this.body = _this.body.replace(body_re, function(str){
          var mod_name, dep_path, f;
          mod_name = str.replace(/.*require\s*\(\s*["']/, '').replace(/['"]\s*\)$/, '');
          dep_path = resolve(dirname(_this.path), mod_name);
          f = BundleFile.get(dep_path, _this.extensions);
          _this.deps.push(f);
          return "require('" + f.name + "')";
        });
        return cbk(null, _this.body);
      });
    }
    return getBody;
  }());
  return BundleFile;
}());
/**
 *  @class Bundler
 *
 *  A bundling class.
 */
Bundler = (function(){
  Bundler.displayName = 'Bundler';
  var last_id, cached, prototype = Bundler.prototype, constructor = Bundler;
  last_id = 0;
  cached = {};
  /**
   *  @constructor
   */
  function Bundler(_arg){
    var extensions, files, f, ext, fn, _res, _i, _len, _this = this;
    extensions = _arg.extensions, files = _arg.files;
    if (typeof files === 'string') {
      files = [files];
    }
    _res = [];
    for (_i = 0, _len = files.length; _i < _len; ++_i) {
      f = files[_i];
      _res.push(resolve(process.cwd() + "/", f));
    }
    files = _res;
    this.files = files;
    this.entry = this.files[0];
    this.extensions = {
      js: function(str){
        return str;
      }
    };
    for (ext in extensions) {
      fn = extensions[ext];
      _fn(ext, fn);
    }
    function _fn(ext, fn){
      return _this.addExtension(ext, function(data, path){
        try {
          return fn(data, path);
        } catch (e) {
          return console.log("!! " + path + ": " + e);
        }
      });
    }
  }
  /**
   *  Add an extension.
   *
   *  @param ext The extension
   *  @param cbk The callback that will handle its compilation.
   */
  prototype.addExtension = (function(){
    function addExtension(ext, cbk){
      return this.extensions[ext] = cbk;
    }
    return addExtension;
  }());
  /**
   *  Resolve a module's path from another.
   *
   *  First, compute the path difference between the two paths,
   *  then look for a file with all the registered extensions.
   *
   *  There is no promise on the order with which the extensions
   *  are looked for.
   *
   *  Once the file is found, it is read and tranformed according
   *  to its extension handler.
   *
   *  @param base The module where the resolving request's been
   *      made.
   *  @param path The path of the module.
   *  @param callback The callback to execute once we're done with
   *      the file. (error, contents)
   */
  prototype.processModules = (function(){
    function processModules(path, callback){
      var file, _this = this;
      file = BundleFile.get(path, this.extensions);
      if (!file.recompile) {
        callback(null);
        return;
      }
      return file.getBody(function(err){
        var loaded, f, _i, _ref, _len, _results = [];
        if (!file.error) {
          if (file.deps.length === 0) {
            callback(err);
          }
          loaded = 0;
          for (_i = 0, _len = (_ref = file.deps).length; _i < _len; ++_i) {
            f = _ref[_i];
            _results.push(_this.processModules(f.path, _fn));
          }
          return _results;
        }
        function _fn(err){
          loaded = loaded + 1;
          if (loaded === file.deps.length) {
            return callback(err);
          }
        }
      });
    }
    return processModules;
  }());
  /**
   *
   */
  prototype.bundleModule = (function(){
    function bundleModule(mod){
      return "__modules_fn['" + mod.name + "'] = function (module) {\n    var exports = module.exports;\n    " + mod.body + "\n};\n__modules['" + mod.name + "'] = {};";
    }
    return bundleModule;
  }());
  prototype.toplevel = (function(){
    function toplevel(){
      /**
       *
       */
      var res;
      function require(path){
        var module;
        if (__modules[path].exports == null) {
          module = __modules[path];
          module.exports = {};
          __modules_fn[path](module);
        }
        return __modules[path].exports;
      }
      res = "var __modules_fn = {};\nvar __modules = {};\n\n" + require.toString();
      return res;
    }
    return toplevel;
  }());
  /**
   *
   */
  prototype.bundle = (function(){
    function bundle(cbk){
      var processed, f, _i, _ref, _len, _results = [], _this = this;
      this.error = false;
      processed = 0;
      for (_i = 0, _len = (_ref = this.files).length; _i < _len; ++_i) {
        f = _ref[_i];
        _results.push(this.processModules(f, _fn));
      }
      return _results;
      function _fn(err){
        var result, modules, get_modules, p, m, f, first, alias_list, _i, _ref, _len;
        if (err) {
          console.log('!! ' + err);
          return;
        }
        processed = processed + 1;
        if (processed === _this.files.length) {
          result = [_this.toplevel()];
          modules = {};
          get_modules = function(f){
            var m, _i, _ref, _len, _results = [];
            if (f.name in modules) {
              return;
            }
            modules[f.name] = f;
            for (_i = 0, _len = (_ref = f.deps).length; _i < _len; ++_i) {
              m = _ref[_i];
              _results.push(get_modules(m));
            }
            return _results;
          };
          for (_i = 0, _len = (_ref = _this.files).length; _i < _len; ++_i) {
            p = _ref[_i];
            get_modules(BundleFile.get(p));
          }
          for (m in modules) {
            f = modules[m];
            if (m.error) {
              console.log("!! " + m.name + " has errors, can't bundle");
              cbk(new Error("Error in one of the source"));
              return;
            }
            result.push(_this.bundleModule(f));
          }
          first = BundleFile.get(_this.files[0]);
          alias_list = [];
          for (m in modules) {
            f = modules[m];
            alias_list.push("__modules['" + f.getRelativeName(first.path) + "'] = __modules['" + f.name + "'];");
            alias_list.push("__modules_fn['" + f.getRelativeName(first.path) + "'] = __modules_fn['" + f.name + "'];");
          }
          result.push(alias_list.join("\n"));
          result = result.join("\n");
          return cbk(null, result);
        }
      }
    }
    return bundle;
  }());
  return Bundler;
}());
exports.Bundler = Bundler;

==> rbuild-0.0.3.tgz: package/lib/bundler.js <==
var dirname, join, resolve, existsSync, basename, readFile, BundleFile, Bundler, _ref;
_ref = require('path'), dirname = _ref.dirname, join = _ref.join, resolve = _ref.resolve, existsSync = _ref.existsSync, basename = _ref.basename;
readFile = require('fs').readFile;
/**
 *  @class BundleFile
 *
 *  Handles dependencies checking and its own compilation.
 */
BundleFile = (function(){
  BundleFile.displayName = 'BundleFile';
  var last_id, cached, body_re, prototype = BundleFile.prototype, constructor = BundleFile;
  last_id = 0;
  cached = {};
  body_re = /\brequire\s*\(\s*("(\\\"|[^"])*"|'(\\\'|[^'])*')\s*\)/g;
  BundleFile.get = (function(){
    function get(path, extensions){
      path = path.replace(/\.[a-zA-Z_]+$/, '');
      if (cached[path]) {
        return cached[path];
      }
      return cached[path] = new BundleFile(path, extensions);
    }
    return get;
  }());
  function BundleFile(path, extensions){
    this.path = path;
    this.extensions = extensions;
    this.compile_fn = null;
    this.error = false;
    this.body = null;
    this.deps = [];
    this.recompile = true;
    this.name = basename(this.path) + "-" + last_id;
    last_id = last_id + 1;
  }
  prototype.getRelativeName = (function(){
    function getRelativeName(path){
      return this.path.replace(dirname(path), '.');
    }
    return getRelativeName;
  }());
  /**
   *  Compiles the module, and parse its contents, triggering the calling of 
   *
   *  @param cbk The callback for when we're done.
   *
   *  @returns An empty string if error, the body of the function otherwise.
   */
  prototype.getBody = (function(){
    function getBody(cbk){
      var ext, fn, realpath, _ref, _this = this;
      if (!this.recompile) {
        cbk(null, this.body);
        return;
      }
      this.recompile = false;
      if (this.compile_fn == null) {
        for (ext in _ref = this.extensions) {
          fn = _ref[ext];
          realpath = this.path + "." + ext;
          if (existsSync(realpath)) {
            this.realpath = realpath;
            this.compile_fn = fn;
            break;
          }
        }
      }
      if (!this.realpath) {
        cbk(new Error("The module " + this.path + " either doesn't exist or doesn't have a valid module handler"));
        return;
      }
      return readFile(this.realpath, 'utf-8', function(err, body){
        if (err) {
          _this.error = true;
          cbk(err, null);
          return;
        }
        console.log("Compiling " + _this.realpath);
        _this.body = _this.compile_fn(body);
        _this.error = false;
        _this.deps = [];
        _this.body = _this.body.replace(body_re, function(str){
          var mod_name, dep_path, f;
          mod_name = str.replace(/.*require\s*\(\s*["']/, '').replace(/['"]\s*\)$/, '');
          dep_path = resolve(dirname(_this.path), mod_name);
          f = BundleFile.get(dep_path, _this.extensions);
          _this.deps.push(f);
          return "require('" + f.name + "')";
        });
        return cbk(null, _this.body);
      });
    }
    return getBody;
  }());
  return BundleFile;
}());
/**
 *  @class Bundler
 *
 *  A bundling class.
 */
Bundler = (function(){
  Bundler.displayName = 'Bundler';
  var last_id, cached, prototype = Bundler.prototype, constructor = Bundler;
  last_id = 0;
  cached = {};
  /**
   *  @constructor
   */
  function Bundler(_arg){
    var extensions, files, f, ext, fn, _res, _i, _len, _this = this;
    extensions = _arg.extensions, files = _arg.files;
    if (typeof files === 'string') {
      files = [files];
    }
    _res = [];
    for (_i = 0, _len = files.length; _i < _len; ++_i) {
      f = files[_i];
      _res.push(resolve(process.cwd() + "/", f));
    }
    files = _res;
    this.files = files;
    this.entry = this.files[0];
    this.extensions = {
      js: function(str){
        return str;
      }
    };
    for (ext in extensions) {
      fn = extensions[ext];
      _fn(ext, fn);
    }
    function _fn(ext, fn){
      return _this.addExtension(ext, function(data, path){
        try {
          return fn(data, path);
        } catch (e) {
          return console.log("!! " + path + ": " + e);
        }
      });
    }
  }
  /**
   *  Add an extension.
   *
   *  @param ext The extension
   *  @param cbk The callback that will handle its compilation.
   */
  prototype.addExtension = (function(){
    function addExtension(ext, cbk){
      return this.extensions[ext] = cbk;
    }
    return addExtension;
  }());
  /**
   *  Resolve a module's path from another.
   *
   *  First, compute the path difference between the two paths,
   *  then look for a file with all the registered extensions.
   *
   *  There is no promise on the order with which the extensions
   *  are looked for.
   *
   *  Once the file is found, it is read and tranformed according
   *  to its extension handler.
   *
   *  @param base The module where the resolving request's been
   *      made.
   *  @param path The path of the module.
   *  @param callback The callback to execute once we're done with
   *      the file. (error, contents)
   */
  prototype.processModules = (function(){
    function processModules(path, callback){
      var file, _this = this;
      file = BundleFile.get(path, this.extensions);
      return file.getBody(function(err){
        var loaded, f, _i, _ref, _len, _results = [];
        if (!file.error) {
          if (file.deps.length === 0) {
            callback(err);
          }
          loaded = 0;
          for (_i = 0, _len = (_ref = file.deps).length; _i < _len; ++_i) {
            f = _ref[_i];
            _results.push(_this.processModules(f.path, _fn));
          }
          return _results;
        }
        function _fn(err){
          loaded = loaded + 1;
          if (loaded === file.deps.length) {
            return callback(err);
          }
        }
      });
    }
    return processModules;
  }());
  /**
   *
   */
  prototype.bundleModule = (function(){
    function bundleModule(mod){
      return "__modules_fn['" + mod.name + "'] = function (module) {\n    var exports = module.exports;\n    " + mod.body + "\n};\n__modules['" + mod.name + "'] = {};";
    }
    return bundleModule;
  }());
  /**
   *  Declaration of the general functions that are to be embedded into
   *  the resulting bundle.
   *
   *  @returns a string with the function declarations we're embedding.
   */
  prototype.toplevel = (function(){
    function toplevel(){
      /**
       *
       */
      var res;
      function require(path){
        var module;
        if (__modules[path].exports == null) {
          module = __modules[path];
          module.exports = {};
          __modules_fn[path](module);
        }
        return __modules[path].exports;
      }
      res = "var __modules_fn = {};\nvar __modules = {};\n\n" + require.toString();
      return res;
    }
    return toplevel;
  }());
  /**
   *  Call the callback with the bundle of all the files.
   */
  prototype.bundle = (function(){
    function bundle(cbk){
      var processed, f, _i, _ref, _len, _results = [], _this = this;
      this.error = false;
      processed = 0;
      for (_i = 0, _len = (_ref = this.files).length; _i < _len; ++_i) {
        f = _ref[_i];
        _results.push(this.processModules(f, _fn));
      }
      return _results;
      function _fn(err){
        var result, modules, get_modules, p, m, f, first, alias_list, _i, _ref, _len;
        if (err) {
          console.log('!! ' + err);
          return;
        }
        processed = processed + 1;
        if (processed === _this.files.length) {
          result = [_this.toplevel()];
          modules = {};
          _this.modules = modules;
          get_modules = function(f){
            var m, _i, _ref, _len, _results = [];
            if (f.name in modules) {
              return;
            }
            modules[f.name] = f;
            for (_i = 0, _len = (_ref = f.deps).length; _i < _len; ++_i) {
              m = _ref[_i];
              _results.push(get_modules(m));
            }
            return _results;
          };
          for (_i = 0, _len = (_ref = _this.files).length; _i < _len; ++_i) {
            p = _ref[_i];
            get_modules(BundleFile.get(p));
          }
          for (m in modules) {
            f = modules[m];
            if (m.error) {
              console.log("!! " + m.name + " has errors, can't bundle");
              cbk(new Error("Error in one of the source"));
              return;
            }
            result.push(_this.bundleModule(f));
          }
          first = BundleFile.get(_this.files[0]);
          alias_list = [];
          for (m in modules) {
            f = modules[m];
            alias_list.push("__modules['" + f.getRelativeName(first.path) + "'] = __modules['" + f.name + "'];");
            alias_list.push("__modules_fn['" + f.getRelativeName(first.path) + "'] = __modules_fn['" + f.name + "'];");
          }
          result.push(alias_list.join("\n"));
          result = result.join("\n");
          return cbk(null, result);
        }
      }
    }
    return bundle;
  }());
  return Bundler;
}());
exports.Bundler = Bundler;
exports.BundleFile = BundleFile;
